pytilities.test.event.helpers.Listener

Package pytilities :: Package test :: Package event :: Module helpers :: Class Listener |
[hide private]
[frames] | no frames]

# Class Listener

source code

    object --+
             |
            Listener

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
handle_noarg(self) | source code
handle_1arg(self, arg) | source code
read(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
| received_noarg
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

Property Details | [hide private]

### received_noarg Get Method: unreachable.received_noarg(self)